@@ -35,8 +35,7 @@ void FindIpkWindow::on_urlButton_clicked()
         return;
     }
 
-    QDesktopServices::openUrl(QUrl("http://www.google.com.ua/search?q="
-                                   + _game->IPKFile()));
+    QDesktopServices::openUrl(QUrl(_game->URL()));
     _urlLaunched = true;
     ui->mainLabel->setText(tr("If you're sure that you downloaded right .ipk "
                               "file to MyDocs/Downloads directory, then "
